darkhistory.physics
===================

.. automodule:: darkhistory.physics

Fundamental Constants
---------------------

.. rubric:: Attributes

.. autosummary::
   :toctree: physics

   mp
   me
   mHe
   hbar
   c
   kB
   alpha
   ele
   mass
   thomson_xsec
   stefboltz
   ele_rad
   ele_compton

Cosmology
----------

.. rubric:: Attributes

.. autosummary::
   :toctree: physics

   h
   H0
   omega_m
   omega_rad
   omega_lambda
   omega_baryon
   omega_DM
   rho_crit
   rho_DM
   rho_baryon
   nB
   nH
   nHe
   nA
   chi
   YHe

.. rubric:: Functions

.. autosummary::
   :toctree: physics

   hubble
   dtdz
   TCMB
   CMB_N_density
   CMB_eng_density
   CMB_spec
   Tm_std
   xHII_std
   xHeII_std
   get_optical_depth
   inj_rate
   struct_boost_func

Atomic and Optical Physics
--------------------------

.. rubric:: Attributes

.. autosummary::
   :toctree: physics

   rydberg
   lya_eng
   lya_freq
   width_2s1s_H
   bohr_rad
   He_ion_eng
   He_exc_lambda
   He_exc_eng
   A_He_21p
   A_He_23P1
   width_21s_1s_He
   
   
.. rubric:: Functions

.. autosummary::
   :toctree: physics
   
   alpha_recomb
   beta_ion
   peebles_C
   C_He
   xe_Saha
   d_xe_Saha_dz
   photo_ion_rate
   photo_ion_xsec
   coll_exc_xsec
   coll_ion_sec_elec_spec
   coll_ion_xsec
   elec_heating_engloss_rate
   f_std
   
.. rubric:: Footnotes

.. [1] N. Aghanim et al. [Planck Collaboration], “Planck 2018 results. VI. Cosmological parameters,” arXiv:1807.06209 [astro-ph.CO]

.. [2] Tanabashi et al. (Particle Data Group), Phys. Rev. D 98, 030001 (2018).

